Discover Packages
github.com/owainlewis/neo
internal
workflow
package
Version:
v0.6.2
Opens a new window with list of versions in this module.
Published: Aug 4, 2026
License: MIT
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
type Event struct {
Generation uint64 `json:"generation,omitempty"`
Action string `json:"action"`
State State `json:"state,omitempty"`
ID string `json:"id,omitempty"`
Detail string `json:"detail,omitempty"`
}
type Item struct {
ID string `json:"id"`
Text string `json:"text"`
Status Status `json:"status,omitempty"`
Detail string `json:"detail,omitempty"`
}
type State struct {
Title string `json:"title,omitempty"`
Items []Item `json:"items"`
}
type Tool struct {
Events chan<- Event
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.